@@ -3,6 +3,9 @@ from copy import deepcopy
 
 from .base import MetricsLayerBase, SQLReplacement
 from .definitions import Definitions
+from .set import Set
+
+SQL_KEYWORDS = {"order", "group", "by", "as", "from", "select", "on", "with"}
 
 
 class Field(MetricsLayerBase, SQLReplacement):
@@ -27,14 +30,19 @@ class Field(MetricsLayerBase, SQLReplacement):
             and definition.get("type") == "count"
         ):
             definition["primary_key_count"] = True
-        # TODO figure out how to handle this weird case
-        # if definition["name"][0] in {"0", "1", "2", "3", "4", "5", "6", "7", "8", "9"}:
-        #     definition["name"] = "_" + definition["name"]
 
         self.view = view
         self.validate(definition)
         super().__init__(definition)
 
+    def id(self, view_only=False, capitalize_alias=False):
+        alias = self.alias()
+        if capitalize_alias:
+            alias = alias.upper()
+        if self.view.explore and not view_only:
+            return f"{self.view.explore.name}.{self.view.name}.{alias}"
+        return f"{self.view.name}.{alias}"
+
     @property
     def sql(self):
         definition = deepcopy(self._definition)
@@ -72,13 +80,25 @@ class Field(MetricsLayerBase, SQLReplacement):
             return label
         return self.alias().replace("_", " ").title()
 
-    def alias(self):
+    @property
+    def drill_fields(self):
+        drill_fields = self._definition.get("drill_fields")
+        if drill_fields:
+            set_definition = {"name": "drill_fields", "fields": drill_fields, "view_name": self.view.name}
+            return Set(set_definition, project=self.view.project).field_names()
+        return drill_fields
+
+    def alias(self, with_view: bool = False):
         if self.field_type == "dimension_group":
             if self.type == "time":
-                return f"{self.name}_{self.dimension_group}"
+                alias = f"{self.name}_{self.dimension_group}"
             elif self.type == "duration":
-                return f"{self.dimension_group}_{self.name}"
-        return self.name
+                alias = f"{self.dimension_group}_{self.name}"
+        else:
+            alias = self.name
+        if with_view:
+            return f"{self.view.name}_{alias}"
+        return alias
 
     def sql_query(
         self, query_type: str = None, query_base_view: str = None, joins: list = [], alias_only: bool = False
@@ -93,7 +113,7 @@ class Field(MetricsLayerBase, SQLReplacement):
         if self.field_type == "measure" and self.type == "number":
             return self.get_referenced_sql_query()
         elif alias_only:
-            return self.alias()
+            return self.alias(with_view=True)
         return self.get_replaced_sql_query(query_type, alias_only=alias_only)
 
     def aggregate_sql_query(
@@ -164,7 +184,7 @@ class Field(MetricsLayerBase, SQLReplacement):
 
         adjusted_sum = f"(CAST(FLOOR(COALESCE({sql}, 0) * ({factor} * 1.0)) AS FLOAT64))"
 
-        pk_sum = f"CAST(FARM_FINGERPRINT({primary_key_sql}) AS BIGNUMERIC)"
+        pk_sum = f"CAST(FARM_FINGERPRINT(CAST({primary_key_sql} AS STRING)) AS BIGNUMERIC)"
 
         sum_with_pk_backout = f"SUM(DISTINCT {adjusted_sum} + {pk_sum}) - SUM(DISTINCT {pk_sum})"
 
@@ -301,14 +321,34 @@ class Field(MetricsLayerBase, SQLReplacement):
             output["sql"] = self.sql_query(query_type)
         return output
 
+    def printable_attributes(self):
+        to_print = [
+            "name",
+            "field_type",
+            "type",
+            "label",
+            "group_label",
+            "hidden",
+            "primary_key",
+            "timeframes",
+            "datatype",
+            "sql",
+        ]
+        attributes = self.to_dict()
+        return {key: attributes.get(key) for key in to_print if attributes.get(key) is not None}
+
     def equal(self, field_name: str):
         # Determine if the field name passed in references this field
+        _, view_name, field_name_only = self.field_name_parts(field_name)
+        if view_name and view_name != self.view.name:
+            return False
+
         if self.field_type == "dimension_group":
-            if field_name in self.dimension_group_names():
-                self.dimension_group = self.get_dimension_group_name(field_name)
+            if field_name_only in self.dimension_group_names():
+                self.dimension_group = self.get_dimension_group_name(field_name_only)
                 return True
             return False
-        return self.name == field_name
+        return self.name == field_name_only
 
     def dimension_group_names(self):
         if self.field_type == "dimension_group" and self.type == "time":
@@ -406,6 +446,19 @@ class Field(MetricsLayerBase, SQLReplacement):
         elif Definitions.bigquery == query_type:
             return f"DATE_TRUNC({sql}, WEEK)"
 
+    def collect_errors(self):
+        if self.field_type == "measure" and self.type == "number":
+            contains_dim = any(
+                field.field_type != "measure" for field in self.get_referenced_sql_query(strings_only=False)
+            )
+            if contains_dim:
+                error_text = (
+                    f"The field {self.name} is a measure with type number, but it's sql references "
+                    "another field that is not a measure. Please correct this reference to the right measure."
+                )
+                return [error_text]
+        return []
+
     def get_referenced_sql_query(self, strings_only=True):
         if self.sql and ("{%" in self.sql or self.sql == ""):
             return None
@@ -549,7 +602,8 @@ class Field(MetricsLayerBase, SQLReplacement):
 
             # isin for strings
             elif len(value.split(", ")) > 1:
-                raise NotImplementedError("TODO: Need to support array syntax in filters")
+                categories = ",".join([f"'{category.strip()}'" for category in value.split(", ")])
+                condition_value = f"is in ({categories})"
 
             else:
                 condition_value = f"= '{value}'"
@@ -603,12 +657,7 @@ class Field(MetricsLayerBase, SQLReplacement):
         return connection_type
 
     @staticmethod
-    def field_name_parts(field_name: str):
-        explore_name, view_name = None, None
-        if field_name.count(".") == 2:
-            explore_name, view_name, name = field_name.split(".")
-        elif field_name.count(".") == 1:
-            view_name, name = field_name.split(".")
-        else:
-            name = field_name
-        return explore_name, view_name, name
+    def _name_is_not_valid_sql(name: str):
+        name_is_keyword = name is not None and name.lower() in SQL_KEYWORDS
+        digit_first_char = name[0] in {"0", "1", "2", "3", "4", "5", "6", "7", "8", "9"}
+        return name_is_keyword or digit_first_char
