@@ -1,4 +1,5 @@
 import os
+from copy import deepcopy
 
 from metrics_layer.core.model.project import Project
 from metrics_layer.core.parse.connections import (
@@ -8,6 +9,7 @@ from metrics_layer.core.parse.connections import (
 )
 
 from .github_repo import GithubRepo, LocalRepo, LookerGithubRepo
+from .manifest import Manifest
 from .project_reader import ProjectReader
 
 
@@ -23,6 +25,7 @@ class MetricsLayerConfiguration:
         connections: list = [],
         target: str = None,
     ):
+        self.profiles_path = None
         self.env_name = target
         self.looker_env = self.env_name
         self.repo, conns = self._resolve_config(repo_config, prefix="METRICS_LAYER", raise_exception=True)
@@ -31,6 +34,12 @@ class MetricsLayerConfiguration:
         )
         self._connections = self._parse_connections(connections) + conns + addtl_conns
         self._project = None
+        self._user = None
+
+    def set_user(self, user: dict):
+        self._user = user
+        if self._project is not None:
+            self._project.set_user(self._user)
 
     @staticmethod
     def get_metrics_layer_configuration(config=None, target: str = None):
@@ -59,6 +68,7 @@ class MetricsLayerConfiguration:
 
     def load(self):
         self._project = self._get_project()
+        self._project.set_user(self._user)
 
     def dump(self, path: str = "./"):
         reader = ProjectReader(repo=self.repo, additional_repo=self.additional_repo)
@@ -66,14 +76,22 @@ class MetricsLayerConfiguration:
         reader.dump(path)
 
     def _get_project(self):
-        reader = ProjectReader(repo=self.repo, additional_repo=self.additional_repo)
+        if self.profiles_path:
+            profiles_dir = os.path.dirname(self.profiles_path)
+        else:
+            profiles_dir = None
+        reader = ProjectReader(
+            repo=self.repo, additional_repo=self.additional_repo, profiles_dir=profiles_dir
+        )
         reader.load()
         connection_lookup = {c.name: c.type for c in self.connections()}
         project = Project(
             models=reader.models,
             views=reader.views,
+            dashboards=reader.dashboards,
             looker_env=self.looker_env,
             connection_lookup=connection_lookup,
+            manifest=Manifest(reader.manifest),
         )
         return project
 
@@ -121,20 +139,28 @@ class MetricsLayerConfiguration:
             or through the Looker API with the following arguments:
             'looker_url': https://company.cloud.looker.com, 'client_id': aefafasdasd,
             'client_secret': adfawdada, 'project_name': yourcompany
+
+            Note: dbt repos require an additional 'warehouse_type' argument
             """
         )
 
     @staticmethod
     def _get_repo_from_environment(prefix: str):
+        warehouse_type = os.getenv(f"{prefix}_WAREHOUSE_TYPE")
         local_repo_param = os.getenv(f"{prefix}_REPO_PATH")
         if local_repo_param:
             repo_type = os.getenv(f"{prefix}_REPO_TYPE")
-            return LocalRepo(repo_path=local_repo_param, repo_type=repo_type)
+            return LocalRepo(repo_path=local_repo_param, repo_type=repo_type, warehouse_type=warehouse_type)
 
         repo_params = [os.getenv(f"{prefix}_{a}") for a in ["REPO_URL", "BRANCH"]]
         if all(repo_params):
             repo_type = os.getenv(f"{prefix}_REPO_TYPE")
-            return GithubRepo(repo_url=repo_params[0], branch=repo_params[1], repo_type=repo_type)
+            return GithubRepo(
+                repo_url=repo_params[0],
+                branch=repo_params[1],
+                repo_type=repo_type,
+                warehouse_type=warehouse_type,
+            )
 
         looker_repo_params = [
             os.getenv(f"{prefix}_{a}") for a in ["LOOKER_URL", "CLIENT_ID", "CLIENT_SECRET", "PROJECT_NAME"]
@@ -155,19 +181,19 @@ class MetricsLayerConfiguration:
 
         clean_prefix = "additional_" if "additional" in prefix.lower() else ""
 
-        metrics_layer_directory = self.get_metrics_layer_directory()
-        profiles_path = os.path.join(metrics_layer_directory, "profiles.yml")
+        metrics_layer_profiles_directory = self.get_metrics_layer_profiles_directory()
+        self.profiles_path = os.path.join(metrics_layer_profiles_directory, "profiles.yml")
 
-        if not os.path.exists(profiles_path):
+        if not os.path.exists(self.profiles_path):
             raise ConfigError(
                 f"""MetricsLayer could not find the profiles.yml file in the directory
-             {profiles_path}, please check that path to ensure the file exists.
+             {self.profiles_path}, please check that path to ensure the file exists.
              If this does not look like the path you specified, make sure you haven't set
              the environment variable METRICS_LAYER_PROFILES_DIR to another value
              which may be overriding the default (~, your home directory)"""
             )
 
-        all_profiles = ProjectReader.read_yaml_file(profiles_path)
+        all_profiles = ProjectReader.read_yaml_file(self.profiles_path)
 
         try:
             profile = all_profiles[config_profile_name]
@@ -175,13 +201,13 @@ class MetricsLayerConfiguration:
             raise ConfigError(
                 f"MetricsLayer could not find the profile "
                 f"{config_profile_name} in options {list(all_profiles.keys())} "
-                f"located in the profiles.yml file at {profiles_path}"
+                f"located in the profiles.yml file at {self.profiles_path}"
             )
 
         if "target" not in profile:
             raise ConfigError(
                 "You need to specify a default target in the "
-                f"file {profiles_path} for profile {config_profile_name}"
+                f"file {self.profiles_path} for profile {config_profile_name}"
             )
 
         if "outputs" not in profile:
@@ -197,24 +223,15 @@ class MetricsLayerConfiguration:
             raise ConfigError(
                 f"MetricsLayer could not find the target "
                 f"{target_name} in outputs {list(profile['outputs'].keys())} "
-                f"located in the profiles.yml file at {profiles_path}"
+                f"located in the profiles.yml file at {self.profiles_path}"
             )
 
         if "looker_env" in target:
             self.looker_env = target["looker_env"]
 
         repo_type = target.get(f"{clean_prefix}repo_type")
-
-        # Local repo
-        path_arg = f"{clean_prefix}repo_path"
-        if path_arg in target:
-            if os.path.isabs(target[path_arg]):
-                path = target[path_arg]
-            else:
-                path = os.path.abspath(
-                    os.path.join(metrics_layer_directory, os.path.expanduser(target[path_arg]))
-                )
-            repo = LocalRepo(repo_path=path, repo_type=repo_type)
+        raw_connection = deepcopy(target)
+        warehouse_type = raw_connection.get("type")
 
         # Github repo
         if all(k in target for k in [f"{clean_prefix}repo_url", f"{clean_prefix}branch"]):
@@ -222,6 +239,7 @@ class MetricsLayerConfiguration:
                 repo_url=target[f"{clean_prefix}repo_url"],
                 branch=target[f"{clean_prefix}branch"],
                 repo_type=repo_type,
+                warehouse_type=warehouse_type,
             )
 
         # Looker API
@@ -235,11 +253,35 @@ class MetricsLayerConfiguration:
             looker_args = {k: target[k] for k in looker_keys}
             repo = LookerGithubRepo(**looker_args, repo_type="lookml")
 
-        connections = [{**c, "directory": metrics_layer_directory} for c in target.get("connections", [])]
-        return repo, MetricsLayerConfiguration._parse_connections(connections)
+        # Local repo
+        path_arg = f"{clean_prefix}repo_path"
+        if path_arg in target:
+            if os.path.isabs(target[path_arg]):
+                path = target[path_arg]
+            else:
+                path = os.path.abspath(
+                    os.path.join(metrics_layer_profiles_directory, os.path.expanduser(target[path_arg]))
+                )
+        else:
+            path = os.getcwd()
+        repo = LocalRepo(repo_path=path, repo_type=repo_type, warehouse_type=warehouse_type)
+
+        connection = {
+            **raw_connection,
+            "name": config_profile_name,
+            "directory": metrics_layer_profiles_directory,
+        }
+        return repo, MetricsLayerConfiguration._parse_connections([connection])
 
     @staticmethod
-    def get_metrics_layer_directory():
+    def get_all_profiles(directory, names_only: bool = False):
+        all_profiles = ProjectReader.read_yaml_file(directory)
+        if names_only:
+            return list(all_profiles.keys())
+        return all_profiles
+
+    @staticmethod
+    def get_metrics_layer_profiles_directory():
         env_specified_location = os.getenv(f"METRICS_LAYER_PROFILES_DIR")
         if env_specified_location:
             if os.path.isabs(env_specified_location):
@@ -247,9 +289,9 @@ class MetricsLayerConfiguration:
             else:
                 return os.path.join(os.getcwd(), os.path.abspath(env_specified_location))
 
-        # System default home directory
+        # System default home directory to dbt profiles dir
         home = os.path.expanduser("~")
-        location = os.path.join(home, ".metrics_layer/")
+        location = os.path.join(home, ".dbt/")
         return location
 
     @staticmethod
