@@ -2,12 +2,11 @@ import os
 import shutil
 from glob import glob
 
+import git
+import requests
+
 from metrics_layer.core import utils
 
-lazy_git = utils.lazy_import("git")
-lazy_requests = utils.lazy_import("requests")
-
-
 BASE_PATH = os.path.dirname(__file__)
 
 
@@ -24,6 +23,13 @@ class BaseRepo:
         yaml_files += list(self.search(pattern="*.yaml"))
         n_yaml_files = len(yaml_files)
 
+        # TODO Need to decide if we will support this
+        # dbt_files = list(self.search(pattern="dbt_project.yml"))
+        # dbt_files += list(self.search(pattern="dbt_project.yml"))
+        # n_dbt_files = len(dbt_files)
+
+        # if n_dbt_files > 0:
+        #     return "dbt"
         if n_looker_files > n_yaml_files:
             return "lookml"
         return "metrics_layer"
@@ -39,9 +45,10 @@ class BaseRepo:
 
 
 class LocalRepo(BaseRepo):
-    def __init__(self, repo_path: str, repo_type: str = None) -> None:
+    def __init__(self, repo_path: str, repo_type: str = None, warehouse_type: str = None) -> None:
         self.repo_path = repo_path
         self.repo_type = repo_type
+        self.warehouse_type = warehouse_type
         self.folder = f"{os.path.join(BASE_PATH, self.repo_path)}/"
 
     def search(self, pattern: str):
@@ -56,9 +63,10 @@ class LocalRepo(BaseRepo):
 
 
 class GithubRepo(BaseRepo):
-    def __init__(self, repo_url: str, branch: str, repo_type: str = None) -> None:
+    def __init__(self, repo_url: str, branch: str, repo_type: str = None, warehouse_type: str = None) -> None:
         self.repo_url = repo_url
         self.repo_type = repo_type
+        self.warehouse_type = warehouse_type
         self.repo_name = utils.generate_uuid()
         self.repo_destination = os.path.join(BASE_PATH, self.repo_name)
         self.folder = f"{self.repo_destination}/"
@@ -82,7 +90,7 @@ class GithubRepo(BaseRepo):
     def fetch_github_repo(repo_url: str, repo_destination: str, branch: str):
         if os.path.exists(repo_destination) and os.path.isdir(repo_destination):
             shutil.rmtree(repo_destination)
-        lazy_git.Repo.clone_from(repo_url, to_path=repo_destination, branch=branch, depth=1)
+        git.Repo.clone_from(repo_url, to_path=repo_destination, branch=branch, depth=1)
 
 
 class LookerGithubRepo(BaseRepo):
@@ -115,13 +123,13 @@ class LookerGithubRepo(BaseRepo):
     def get_looker_projects(self):
         token = self.get_looker_oauth_token(self.looker_url, self.client_id, self.client_secret)
         headers = {"Authorization": f"token {token}"}
-        response = lazy_requests.get(f"{self.looker_url}/api/3.1/projects", headers=headers)
+        response = requests.get(f"{self.looker_url}/api/3.1/projects", headers=headers)
         return response.json()
 
     @staticmethod
     def get_looker_oauth_token(looker_url, client_id, client_secret):
         data = {"client_id": client_id, "client_secret": client_secret}
-        response = lazy_requests.post(f"{looker_url}/api/3.1/login", data=data)
+        response = requests.post(f"{looker_url}/api/3.1/login", data=data)
         if response.status_code == 403:
             raise ValueError("Looker credentials not valid, please check your credentials")
         return response.json()["access_token"]
