@@ -1,10 +1,9 @@
 from typing import List
 
+import networkx
+
 from metrics_layer.core.model.base import MetricsLayerBase
 from metrics_layer.core.sql.query_errors import ParseError
-from metrics_layer.core.utils import lazy_import
-
-lazy_networkx = lazy_import("networkx")
 
 
 class MetricsLayerDesign:
@@ -18,10 +17,11 @@ class MetricsLayerDesign:
         self.project = project
 
     def views(self) -> List[MetricsLayerBase]:
-        return [self.project.get_view(name, explore=self.explore) for name in self.explore.view_names()]
+        return self.project.views(explore_name=self.explore.name)
 
     def joins(self) -> List[MetricsLayerBase]:
-        fields_in_query = list(self.field_lookup.values())
+        _, access_filter_fields = self.get_access_filter()
+        fields_in_query = list(self.field_lookup.values()) + access_filter_fields
         required_views = list(set([v for field in fields_in_query for v in field.required_views()]))
         if self.explore.always_join:
             required_views.extend(self.explore.always_join)
@@ -34,11 +34,13 @@ class MetricsLayerDesign:
     def _find_needed_joins(self, view_name: str, joins_already_added: list):
         joins_to_add = []
 
-        join_already_added = any(view_name == j.name for j in joins_already_added)
+        join_already_added = any(view_name == j.from_ for j in joins_already_added)
         if not join_already_added and view_name != self.explore.from_:
-            join = self.explore.get_join(view_name)
+            join = self.explore.get_join(view_name, by_view_name=True)
             if join is None:
-                raise ValueError(f"Could not locate join named {view_name} for explore {self.explore.name}")
+                raise ValueError(
+                    f"Could not locate join from view {view_name} for explore {self.explore.name}"
+                )
             joins_to_add.append(join)
             for view_name in join.required_views():
                 joins_to_add.extend(self._find_needed_joins(view_name, joins_already_added + [join]))
@@ -48,13 +50,13 @@ class MetricsLayerDesign:
         if len(joins_needed) == 0:
             return []
 
-        G = lazy_networkx.DiGraph()
+        G = networkx.DiGraph()
         for join in joins_needed:
             for view_name in join.required_views():
-                G.add_edge(view_name, join.name)
-        ordered_names = list(lazy_networkx.bfs_tree(G, source=self.base_view_name))
+                G.add_edge(view_name, join.from_)
+        ordered_names = list(networkx.bfs_tree(G, source=self.base_view_name))
         # Skip the first one because that's *always* the base of the explore
-        return [self.explore.get_join(name) for name in ordered_names[1:]]
+        return [self.explore.get_join(name, by_view_name=True) for name in ordered_names[1:]]
 
     def get_view(self, name: str) -> MetricsLayerBase:
         try:
@@ -68,6 +70,21 @@ class MetricsLayerDesign:
     def get_field(self, field_name: str, view_name: str = None) -> MetricsLayerBase:
         return self.project.get_field(field_name, view_name=view_name, explore_name=self.explore.name)
 
+    def get_access_filter(self):
+        if self.explore.access_filters:
+            conditions, fields = [], []
+            for condition_set in self.explore.access_filters:
+                field = self.project.get_field(condition_set["field"], explore_name=self.explore.name)
+                sql = field.sql_query(self.query_type)
+                user_attribute_value = condition_set["user_attribute"]
+
+                if self.project._user and self.project._user.get(user_attribute_value):
+                    condition = f"{sql} = '{self.project._user[user_attribute_value]}'"
+                    conditions.append(condition)
+                    fields.append(field)
+            return " and ".join(conditions), fields
+        return None, []
+
     @property
     def base_view_name(self):
         return self.explore.from_
